qnum testing — Runestone Interactive Overview

# qnum testing

# Fill in the Blank

Before-5-After: Fill in the blanks to make the following sentence: “The red car drove away.”

The car drove .

Test 2 - test a numeric range.

Before-6-After:

What is the solution to the following:

\(2 * \pi =\) .

# Error testing

System Message: ERROR/3 (/home/bmiller/Runestone/RunestoneComponents/runestone/fitb/test/_sources/index.rst, line 38)

Content block expected for the “fillintheblank” directive; none found.

    .. fillintheblank:: error1_no_content

System Message: ERROR/3 (/home/bmiller/Runestone/RunestoneComponents/runestone/fitb/test/_sources/index.rst, line 40)

On line 42, the last item in a fill-in-the-blank question must be a bulleted list.

    .. fillintheblank:: error2

        No feedback provided.

System Message: ERROR/3 (/home/bmiller/Runestone/RunestoneComponents/runestone/fitb/test/_sources/index.rst, line 44)

On line 48, each list item in a fill-in-the-blank problems must contain only one item, a field list.

    .. fillintheblank:: error3

        List contents aren't field lists.

        -   I'm not a field list.

Before-10-After: Not enough feedback.

# Regex testing

Before-11-After: Complete the sentence: had a lamb. One plus one is: (note that if there aren’t enough blanks for the feedback given, they’re added to the end of the problem. So, we don’t need to specify a blank here.)

Before-12-After: Windows system files are stored in: .

Before-13-After: Python lists are declared using: .

You have attempted of activities on this page